# $Id: Attributes.pm 35513 2011-09-05 16:16:43Z wsl $
# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Attributes.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Attributes;

use Aselect::UI::Attributes::Request;
use Aselect::UI::Attributes::Document;

use Aselect::Handler -self;

sub handle {
	my $req = new Aselect::UI::Attributes::Request(cfg => $self, ctx => shift);
	my $doc = new Aselect::UI::Attributes::Document(req => $req);
	return $doc->response;
}
